pub struct AdministratorWebToken {
pub token: Option<String>,
}Expand description
A token authorizing an admin to access an iframe.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- create web token enterprises (response)
Fields
token: Option<String>An opaque token to be passed to the Play front-end to generate an iframe.