pub struct AdministratorWebTokenSpecPlaySearch {
pub approve_apps: Option<bool>,
pub enabled: Option<bool>,
}Expand description
There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
approve_apps: Option<bool>Allow access to the iframe in approve mode. Default is false.
enabled: Option<bool>Whether the managed Play Search apps page is displayed. Default is true.