pub struct AppRestrictionsSchemaRestrictionRestrictionValue {
pub type_: Option<String>,
pub value_bool: Option<bool>,
pub value_integer: Option<i32>,
pub value_multiselect: Option<Vec<String>>,
pub value_string: Option<String>,
}Expand description
A typed value for the restriction.
This type is not used in any activity, and only used as part of another schema.
Fields
type_: Option<String>The type of the value being provided.
value_bool: Option<bool>The boolean value - this will only be present if type is bool.
value_integer: Option<i32>The integer value - this will only be present if type is integer.
value_multiselect: Option<Vec<String>>The list of string values - this will only be present if type is multiselect.
value_string: Option<String>The string value - this will be present for types string, choice and hidden.