pub struct AppVersion {
pub is_production: Option<bool>,
pub target_sdk_version: Option<i32>,
pub track: Option<String>,
pub track_id: Option<Vec<String>>,
pub version_code: Option<i32>,
pub version_string: Option<String>,
}Expand description
This represents a single version of the app.
This type is not used in any activity, and only used as part of another schema.
Fields
is_production: Option<bool>True if this version is a production APK.
target_sdk_version: Option<i32>The SDK version this app targets, as specified in the manifest of the APK. See http://developer.android.com/guide/topics/manifest/uses-sdk-element.html
track: Option<String>Deprecated, use trackId instead.
track_id: Option<Vec<String>>Track ids that the app version is published in. Replaces the track field (deprecated), but doesn’t include the production track (see isProduction instead).
version_code: Option<i32>Unique increasing identifier for the app version.
version_string: Option<String>The string used in the Play store by the app developer to identify the version. The string is not necessarily unique or localized (for example, the string could be “1.4”).