pub struct AuthenticationToken {
pub token: Option<String>,
}Expand description
An AuthenticationToken is used by the EMM’s device policy client on a device to provision the given EMM-managed user on that device.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- generate authentication token users (response)
Fields
token: Option<String>The authentication token to be passed to the device policy client on the device where it can be used to provision the account for which this token was generated.