pub struct AutoInstallConstraint {
pub charging_state_constraint: Option<String>,
pub device_idle_state_constraint: Option<String>,
pub network_type_constraint: Option<String>,
}Expand description
The auto-install constraint. Defines a set of restrictions for installation. At least one of the fields must be set.
This type is not used in any activity, and only used as part of another schema.
Fields
charging_state_constraint: Option<String>Charging state constraint.
device_idle_state_constraint: Option<String>Device idle state constraint.
network_type_constraint: Option<String>Network type constraint.