pub struct AutoInstallPolicy {
pub auto_install_constraint: Option<Vec<AutoInstallConstraint>>,
pub auto_install_mode: Option<String>,
pub auto_install_priority: Option<i32>,
pub minimum_version_code: Option<i32>,
}Expand description
There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
auto_install_constraint: Option<Vec<AutoInstallConstraint>>The constraints for auto-installing the app. You can specify a maximum of one constraint.
auto_install_mode: Option<String>The auto-install mode. If unset, defaults to “doNotAutoInstall”. An app is automatically installed regardless of a set maintenance window.
auto_install_priority: Option<i32>The priority of the install, as an unsigned integer. A lower number means higher priority.
minimum_version_code: Option<i32>The minimum version of the app. If a lower version of the app is installed, then the app will be auto-updated according to the auto-install constraints, instead of waiting for the regular auto-update. You can set a minimum version code for at most 20 apps per device.