ConfigurationVariables

Struct ConfigurationVariables 

pub struct ConfigurationVariables {
    pub mcm_id: Option<String>,
    pub variable_set: Option<Vec<VariableSet>>,
}
A configuration variables resource contains the managed configuration settings ID to be applied to a single user, as well as the variable set that is attributed to the user. The variable set will be used to replace placeholders in the managed configuration settings.

This type is not used in any activity, and only used as part of another schema.

Fields

mcm_id: Option<String>

The ID of the managed configurations settings.

variable_set: Option<Vec<VariableSet>>

The variable set that is attributed to the user.