pub struct DeviceReportUpdateEvent {
pub device_id: Option<String>,
pub report: Option<DeviceReport>,
pub user_id: Option<String>,
}Expand description
An event generated when an updated device report is available.
This type is not used in any activity, and only used as part of another schema.
Fields
device_id: Option<String>The Android ID of the device. This field will always be present.
report: Option<DeviceReport>The device report updated with the latest app states. This field will always be present.
user_id: Option<String>The ID of the user. This field will always be present.