pub struct DevicesListResponse {
pub device: Option<Vec<Device>>,
}Expand description
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list devices (response)
Fields
device: Option<Vec<Device>>A managed device.