pub struct EntitlementMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on entitlement resources.
It is not used directly, but through the AndroidEnterprise hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_androidenterprise1 as androidenterprise1;
use androidenterprise1::{AndroidEnterprise, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = AndroidEnterprise::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `delete(...)`, `get(...)`, `list(...)` and `update(...)`
// to build up your call.
let rb = hub.entitlements();Implementations
Sourceimpl<'a, C> EntitlementMethods<'a, C>
impl<'a, C> EntitlementMethods<'a, C>
Sourcepub fn delete(
&self,
enterprise_id: &str,
user_id: &str,
entitlement_id: &str,
) -> EntitlementDeleteCall<'a, C>
pub fn delete( &self, enterprise_id: &str, user_id: &str, entitlement_id: &str, ) -> EntitlementDeleteCall<'a, C>
Create a builder to help you perform the following task:
Removes an entitlement to an app for a user. Note: This item has been deprecated. New integrations cannot use this method and can refer to our new recommendations.
Arguments
enterpriseId- The ID of the enterprise.userId- The ID of the user.entitlementId- The ID of the entitlement (a product ID), e.g. “app:com.google.android.gm”.
Sourcepub fn get(
&self,
enterprise_id: &str,
user_id: &str,
entitlement_id: &str,
) -> EntitlementGetCall<'a, C>
pub fn get( &self, enterprise_id: &str, user_id: &str, entitlement_id: &str, ) -> EntitlementGetCall<'a, C>
Create a builder to help you perform the following task:
Retrieves details of an entitlement. Note: This item has been deprecated. New integrations cannot use this method and can refer to our new recommendations.
Arguments
enterpriseId- The ID of the enterprise.userId- The ID of the user.entitlementId- The ID of the entitlement (a product ID), e.g. “app:com.google.android.gm”.
Sourcepub fn list(
&self,
enterprise_id: &str,
user_id: &str,
) -> EntitlementListCall<'a, C>
pub fn list( &self, enterprise_id: &str, user_id: &str, ) -> EntitlementListCall<'a, C>
Create a builder to help you perform the following task:
Lists all entitlements for the specified user. Only the ID is set. Note: This item has been deprecated. New integrations cannot use this method and can refer to our new recommendations.
Arguments
enterpriseId- The ID of the enterprise.userId- The ID of the user.
Sourcepub fn update(
&self,
request: Entitlement,
enterprise_id: &str,
user_id: &str,
entitlement_id: &str,
) -> EntitlementUpdateCall<'a, C>
pub fn update( &self, request: Entitlement, enterprise_id: &str, user_id: &str, entitlement_id: &str, ) -> EntitlementUpdateCall<'a, C>
Create a builder to help you perform the following task:
Adds or updates an entitlement to an app for a user. Note: This item has been deprecated. New integrations cannot use this method and can refer to our new recommendations.
Arguments
request- No description provided.enterpriseId- The ID of the enterprise.userId- The ID of the user.entitlementId- The ID of the entitlement (a product ID), e.g. “app:com.google.android.gm”.