pub struct EntitlementsListResponse {
pub entitlement: Option<Vec<Entitlement>>,
}Expand description
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list entitlements (response)
Fields
entitlement: Option<Vec<Entitlement>>An entitlement of a user to a product (e.g. an app). For example, a free app that they have installed, or a paid app that they have been allocated a license to.