pub struct InstallFailureEvent {
pub device_id: Option<String>,
pub failure_details: Option<String>,
pub failure_reason: Option<String>,
pub product_id: Option<String>,
pub user_id: Option<String>,
}Expand description
An event generated when an app installation failed on a device
This type is not used in any activity, and only used as part of another schema.
Fields
device_id: Option<String>The Android ID of the device. This field will always be present.
failure_details: Option<String>Additional details on the failure if applicable.
failure_reason: Option<String>The reason for the installation failure. This field will always be present.
product_id: Option<String>The id of the product (e.g. “app:com.google.android.gm”) for which the install failure event occured. This field will always be present.
user_id: Option<String>The ID of the user. This field will always be present.