pub struct KeyedAppState {
pub data: Option<String>,
pub key: Option<String>,
pub message: Option<String>,
pub severity: Option<String>,
pub state_timestamp_millis: Option<i64>,
}Expand description
Represents a keyed app state containing a key, timestamp, severity level, optional description, and optional data.
This type is not used in any activity, and only used as part of another schema.
Fields
data: Option<String>Additional field intended for machine-readable data. For example, a number or JSON object. To prevent XSS, we recommend removing any HTML from the data before displaying it.
key: Option<String>Key indicating what the app is providing a state for. The content of the key is set by the app’s developer. To prevent XSS, we recommend removing any HTML from the key before displaying it. This field will always be present.
message: Option<String>Free-form, human-readable message describing the app state. For example, an error message. To prevent XSS, we recommend removing any HTML from the message before displaying it.
severity: Option<String>Severity of the app state. This field will always be present.
state_timestamp_millis: Option<i64>Timestamp of when the app set the state in milliseconds since epoch. This field will always be present.