pub struct MaintenanceWindow {
pub duration_ms: Option<i64>,
pub start_time_after_midnight_ms: Option<i64>,
}Expand description
Maintenance window for managed Google Play Accounts. This allows Play store to update the apps on the foreground in the designated window.
This type is not used in any activity, and only used as part of another schema.
Fields
duration_ms: Option<i64>Duration of the maintenance window, in milliseconds. The duration must be between 30 minutes and 24 hours (inclusive).
start_time_after_midnight_ms: Option<i64>Start time of the maintenance window, in milliseconds after midnight on the device. Windows can span midnight.