pub struct ManagedConfiguration {
pub configuration_variables: Option<ConfigurationVariables>,
pub kind: Option<String>,
pub managed_property: Option<Vec<ManagedProperty>>,
pub product_id: Option<String>,
}Expand description
Deprecated: New integrations cannot use this method and can refer to our new recommendations
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- get managedconfigurationsfordevice (response)
- update managedconfigurationsfordevice (request|response)
- get managedconfigurationsforuser (response)
- update managedconfigurationsforuser (request|response)
Fields
configuration_variables: Option<ConfigurationVariables>Contains the ID of the managed configuration profile and the set of configuration variables (if any) defined for the user.
kind: Option<String>Deprecated.
managed_property: Option<Vec<ManagedProperty>>The set of managed properties for this configuration.
product_id: Option<String>The ID of the product that the managed configuration is for, e.g. “app:com.google.android.gm”.