pub struct ManagedConfigurationsForDeviceListResponse {
pub managed_configuration_for_device: Option<Vec<ManagedConfiguration>>,
}Expand description
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list managedconfigurationsfordevice (response)
Fields
managed_configuration_for_device: Option<Vec<ManagedConfiguration>>A managed configuration for an app on a specific device.