pub struct ManagedConfigurationsSettings {
pub last_updated_timestamp_millis: Option<i64>,
pub mcm_id: Option<String>,
pub name: Option<String>,
}Expand description
A managed configurations settings resource contains the set of managed properties that have been configured for an Android app to be applied to a set of users. The app’s developer would have defined configurable properties in the managed configurations schema.
This type is not used in any activity, and only used as part of another schema.
Fields
last_updated_timestamp_millis: Option<i64>The last updated time of the managed configuration settings in milliseconds since 1970-01-01T00:00:00Z.
mcm_id: Option<String>The ID of the managed configurations settings.
name: Option<String>The name of the managed configurations settings.