pub struct ManagedconfigurationsfordeviceMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on managedconfigurationsfordevice resources.
It is not used directly, but through the AndroidEnterprise hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_androidenterprise1 as androidenterprise1;
use androidenterprise1::{AndroidEnterprise, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = AndroidEnterprise::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `delete(...)`, `get(...)`, `list(...)` and `update(...)`
// to build up your call.
let rb = hub.managedconfigurationsfordevice();Implementations
Sourceimpl<'a, C> ManagedconfigurationsfordeviceMethods<'a, C>
impl<'a, C> ManagedconfigurationsfordeviceMethods<'a, C>
Sourcepub fn delete(
&self,
enterprise_id: &str,
user_id: &str,
device_id: &str,
managed_configuration_for_device_id: &str,
) -> ManagedconfigurationsfordeviceDeleteCall<'a, C>
pub fn delete( &self, enterprise_id: &str, user_id: &str, device_id: &str, managed_configuration_for_device_id: &str, ) -> ManagedconfigurationsfordeviceDeleteCall<'a, C>
Create a builder to help you perform the following task:
Removes a per-device managed configuration for an app for the specified device.
Arguments
enterpriseId- The ID of the enterprise.userId- The ID of the user.deviceId- The Android ID of the device.managedConfigurationForDeviceId- The ID of the managed configuration (a product ID), e.g. “app:com.google.android.gm”.
Sourcepub fn get(
&self,
enterprise_id: &str,
user_id: &str,
device_id: &str,
managed_configuration_for_device_id: &str,
) -> ManagedconfigurationsfordeviceGetCall<'a, C>
pub fn get( &self, enterprise_id: &str, user_id: &str, device_id: &str, managed_configuration_for_device_id: &str, ) -> ManagedconfigurationsfordeviceGetCall<'a, C>
Create a builder to help you perform the following task:
Retrieves details of a per-device managed configuration.
Arguments
enterpriseId- The ID of the enterprise.userId- The ID of the user.deviceId- The Android ID of the device.managedConfigurationForDeviceId- The ID of the managed configuration (a product ID), e.g. “app:com.google.android.gm”.
Sourcepub fn list(
&self,
enterprise_id: &str,
user_id: &str,
device_id: &str,
) -> ManagedconfigurationsfordeviceListCall<'a, C>
pub fn list( &self, enterprise_id: &str, user_id: &str, device_id: &str, ) -> ManagedconfigurationsfordeviceListCall<'a, C>
Create a builder to help you perform the following task:
Lists all the per-device managed configurations for the specified device. Only the ID is set.
Arguments
enterpriseId- The ID of the enterprise.userId- The ID of the user.deviceId- The Android ID of the device.
Sourcepub fn update(
&self,
request: ManagedConfiguration,
enterprise_id: &str,
user_id: &str,
device_id: &str,
managed_configuration_for_device_id: &str,
) -> ManagedconfigurationsfordeviceUpdateCall<'a, C>
pub fn update( &self, request: ManagedConfiguration, enterprise_id: &str, user_id: &str, device_id: &str, managed_configuration_for_device_id: &str, ) -> ManagedconfigurationsfordeviceUpdateCall<'a, C>
Create a builder to help you perform the following task:
Adds or updates a per-device managed configuration for an app for the specified device.
Arguments
request- No description provided.enterpriseId- The ID of the enterprise.userId- The ID of the user.deviceId- The Android ID of the device.managedConfigurationForDeviceId- The ID of the managed configuration (a product ID), e.g. “app:com.google.android.gm”.