pub struct NewDeviceEvent {
pub device_id: Option<String>,
pub dpc_package_name: Option<String>,
pub management_type: Option<String>,
pub user_id: Option<String>,
}Expand description
An event generated when a new device is ready to be managed.
This type is not used in any activity, and only used as part of another schema.
Fields
device_id: Option<String>The Android ID of the device. This field will always be present.
dpc_package_name: Option<String>Policy app on the device.
management_type: Option<String>Identifies the extent to which the device is controlled by an Android EMM in various deployment configurations. Possible values include: - “managedDevice”, a device where the DPC is set as device owner, - “managedProfile”, a device where the DPC is set as profile owner.
user_id: Option<String>The ID of the user. This field will always be present.