pub struct Notification {
pub app_restrictions_schema_change_event: Option<AppRestrictionsSchemaChangeEvent>,
pub app_update_event: Option<AppUpdateEvent>,
pub device_report_update_event: Option<DeviceReportUpdateEvent>,
pub enterprise_id: Option<String>,
pub enterprise_upgrade_event: Option<EnterpriseUpgradeEvent>,
pub install_failure_event: Option<InstallFailureEvent>,
pub new_device_event: Option<NewDeviceEvent>,
pub new_permissions_event: Option<NewPermissionsEvent>,
pub notification_type: Option<String>,
pub product_approval_event: Option<ProductApprovalEvent>,
pub product_availability_change_event: Option<ProductAvailabilityChangeEvent>,
pub timestamp_millis: Option<i64>,
}Expand description
A notification of one event relating to an enterprise.
This type is not used in any activity, and only used as part of another schema.
Fields
app_restrictions_schema_change_event: Option<AppRestrictionsSchemaChangeEvent>Notifications about new app restrictions schema changes.
app_update_event: Option<AppUpdateEvent>Notifications about app updates.
device_report_update_event: Option<DeviceReportUpdateEvent>Notifications about device report updates.
enterprise_id: Option<String>The ID of the enterprise for which the notification is sent. This will always be present.
enterprise_upgrade_event: Option<EnterpriseUpgradeEvent>Notifications about enterprise upgrade.
install_failure_event: Option<InstallFailureEvent>Notifications about an app installation failure.
new_device_event: Option<NewDeviceEvent>Notifications about new devices.
new_permissions_event: Option<NewPermissionsEvent>Notifications about new app permissions.
notification_type: Option<String>Type of the notification.
product_approval_event: Option<ProductApprovalEvent>Notifications about changes to a product’s approval status.
product_availability_change_event: Option<ProductAvailabilityChangeEvent>Notifications about product availability changes.
timestamp_millis: Option<i64>The time when the notification was published in milliseconds since 1970-01-01T00:00:00Z. This will always be present.