pub struct NotificationSet {
pub notification: Option<Vec<Notification>>,
pub notification_set_id: Option<String>,
}Expand description
A resource returned by the PullNotificationSet API, which contains a collection of notifications for enterprises associated with the service account authenticated for the request.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- pull notification set enterprises (response)
Fields
notification: Option<Vec<Notification>>The notifications received, or empty if no notifications are present.
notification_set_id: Option<String>The notification set ID, required to mark the notification as received with the Enterprises.AcknowledgeNotification API. This will be omitted if no notifications are present.