pub struct PermissionMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on permission resources.
It is not used directly, but through the AndroidEnterprise hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_androidenterprise1 as androidenterprise1;
use androidenterprise1::{AndroidEnterprise, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = AndroidEnterprise::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `get(...)`
// to build up your call.
let rb = hub.permissions();Implementations
Sourceimpl<'a, C> PermissionMethods<'a, C>
impl<'a, C> PermissionMethods<'a, C>
Sourcepub fn get(&self, permission_id: &str) -> PermissionGetCall<'a, C>
pub fn get(&self, permission_id: &str) -> PermissionGetCall<'a, C>
Create a builder to help you perform the following task:
Retrieves details of an Android app permission for display to an enterprise admin.
Arguments
permissionId- The ID of the permission.