pub struct StoreLayoutClustersListResponse {
pub cluster: Option<Vec<StoreCluster>>,
}Expand description
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list storelayoutclusters (response)
Fields
cluster: Option<Vec<StoreCluster>>A store cluster of an enterprise.