pub struct StorePage {
pub id: Option<String>,
pub link: Option<Vec<String>>,
pub name: Option<Vec<LocalizedText>>,
}Expand description
Definition of a managed Google Play store page, made of a localized name and links to other pages. A page also contains clusters defined as a subcollection.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- get storelayoutpages (response)
- insert storelayoutpages (request|response)
- update storelayoutpages (request|response)
Fields
id: Option<String>Unique ID of this page. Assigned by the server. Immutable once assigned.
link: Option<Vec<String>>Ordered list of pages a user should be able to reach from this page. The list can’t include this page. It is recommended that the basic pages are created first, before adding the links between pages. The API doesn’t verify that the pages exist or the pages are reachable.
name: Option<Vec<LocalizedText>>Ordered list of localized strings giving the name of this page. The text displayed is the one that best matches the user locale, or the first entry if there is no good match. There needs to be at least one entry.