pub struct TrackInfo {
pub track_alias: Option<String>,
pub track_id: Option<String>,
}Expand description
Id to name association of a track.
This type is not used in any activity, and only used as part of another schema.
Fields
track_alias: Option<String>A modifiable name for a track. This is the visible name in the play developer console.
track_id: Option<String>Unmodifiable, unique track identifier. This identifier is the releaseTrackId in the url of the play developer console page that displays the track information.