pub struct VariableSet {
pub placeholder: Option<String>,
pub user_value: Option<String>,
}Expand description
A variable set is a key-value pair of EMM-provided placeholders and its corresponding value, which is attributed to a user. For example, $FIRSTNAME could be a placeholder, and its value could be Alice. Placeholders should start with a ‘$’ sign and should be alphanumeric only.
This type is not used in any activity, and only used as part of another schema.
Fields
placeholder: Option<String>The placeholder string; defined by EMM.
user_value: Option<String>The value of the placeholder, specific to the user.