WebApp

Struct WebApp 

pub struct WebApp {
    pub display_mode: Option<String>,
    pub icons: Option<Vec<WebAppIcon>>,
    pub is_published: Option<bool>,
    pub start_url: Option<String>,
    pub title: Option<String>,
    pub version_code: Option<i64>,
    pub web_app_id: Option<String>,
}
A WebApps resource represents a web app created for an enterprise. Web apps are published to managed Google Play and can be distributed like other Android apps. On a user’s device, a web app opens its specified URL.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

display_mode: Option<String>

The display mode of the web app. Possible values include: - “minimalUi”, the device’s status bar, navigation bar, the app’s URL, and a refresh button are visible when the app is open. For HTTP URLs, you can only select this option. - “standalone”, the device’s status bar and navigation bar are visible when the app is open. - “fullScreen”, the app opens in full screen mode, hiding the device’s status and navigation bars. All browser UI elements, page URL, system status bar and back button are not visible, and the web app takes up the entirety of the available display area.

icons: Option<Vec<WebAppIcon>>

A list of icons representing this website. If absent, a default icon (for create) or the current icon (for update) will be used.

is_published: Option<bool>

A flag whether the app has been published to the Play store yet.

start_url: Option<String>

The start URL, i.e. the URL that should load when the user opens the application.

title: Option<String>

The title of the web app as displayed to the user (e.g., amongst a list of other applications, or as a label for an icon).

version_code: Option<i64>

The current version of the app. Note that the version can automatically increase during the lifetime of the web app, while Google does internal housekeeping to keep the web app up-to-date.

web_app_id: Option<String>

The ID of the application. A string of the form “app:” where the package name always starts with the prefix “com.google.enterprise.webapp.” followed by a random id.