pub struct WebAppsListResponse {
pub web_app: Option<Vec<WebApp>>,
}Expand description
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list webapps (response)
Fields
web_app: Option<Vec<WebApp>>The manifest describing a web app.