pub struct AdministratorWebTokenSpec {
pub managed_configurations: Option<AdministratorWebTokenSpecManagedConfigurations>,
pub parent: Option<String>,
pub permission: Option<Vec<String>>,
pub play_search: Option<AdministratorWebTokenSpecPlaySearch>,
pub private_apps: Option<AdministratorWebTokenSpecPrivateApps>,
pub store_builder: Option<AdministratorWebTokenSpecStoreBuilder>,
pub web_apps: Option<AdministratorWebTokenSpecWebApps>,
pub zero_touch: Option<AdministratorWebTokenSpecZeroTouch>,
}Expand description
Specification for a token used to generate iframes. The token specifies what data the admin is allowed to modify and the URI the iframe is allowed to communiate with.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- create web token enterprises (request)
Fields
managed_configurations: Option<AdministratorWebTokenSpecManagedConfigurations>Options for displaying the Managed Configuration page.
parent: Option<String>The URI of the parent frame hosting the iframe. To prevent XSS, the iframe may not be hosted at other URIs. This URI must be https. Use whitespaces to separate multiple parent URIs.
permission: Option<Vec<String>>Deprecated. Use PlaySearch.approveApps.
play_search: Option<AdministratorWebTokenSpecPlaySearch>Options for displaying the managed Play Search apps page.
private_apps: Option<AdministratorWebTokenSpecPrivateApps>Options for displaying the Private Apps page.
store_builder: Option<AdministratorWebTokenSpecStoreBuilder>Options for displaying the Organize apps page.
web_apps: Option<AdministratorWebTokenSpecWebApps>Options for displaying the Web Apps page.
zero_touch: Option<AdministratorWebTokenSpecZeroTouch>Options for displaying the Zero Touch page.