pub struct GroupLicense {
pub acquisition_kind: Option<String>,
pub approval: Option<String>,
pub num_provisioned: Option<i32>,
pub num_purchased: Option<i32>,
pub permissions: Option<String>,
pub product_id: Option<String>,
}Expand description
Deprecated: New integrations cannot use this method and can refer to our new recommendations
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- get grouplicenses (response)
Fields
acquisition_kind: Option<String>How this group license was acquired. “bulkPurchase” means that this Grouplicenses resource was created because the enterprise purchased licenses for this product; otherwise, the value is “free” (for free products).
approval: Option<String>Whether the product to which this group license relates is currently approved by the enterprise. Products are approved when a group license is first created, but this approval may be revoked by an enterprise admin via Google Play. Unapproved products will not be visible to end users in collections, and new entitlements to them should not normally be created.
num_provisioned: Option<i32>The total number of provisioned licenses for this product. Returned by read operations, but ignored in write operations.
num_purchased: Option<i32>The number of purchased licenses (possibly in multiple purchases). If this field is omitted, then there is no limit on the number of licenses that can be provisioned (for example, if the acquisition kind is “free”).
permissions: Option<String>The permission approval status of the product. This field is only set if the product is approved. Possible states are: - “currentApproved”, the current set of permissions is approved, but additional permissions will require the administrator to reapprove the product (If the product was approved without specifying the approved permissions setting, then this is the default behavior.), - “needsReapproval”, the product has unapproved permissions. No additional product licenses can be assigned until the product is reapproved, - “allCurrentAndFutureApproved”, the current permissions are approved and any future permission updates will be automatically approved without administrator review.
product_id: Option<String>The ID of the product that the license is for. For example, “app:com.google.android.gm”.