pub struct ManagedconfigurationsforuserMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on managedconfigurationsforuser resources.
It is not used directly, but through the AndroidEnterprise hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_androidenterprise1 as androidenterprise1;
use androidenterprise1::{AndroidEnterprise, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = AndroidEnterprise::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `delete(...)`, `get(...)`, `list(...)` and `update(...)`
// to build up your call.
let rb = hub.managedconfigurationsforuser();Implementations
Sourceimpl<'a, C> ManagedconfigurationsforuserMethods<'a, C>
impl<'a, C> ManagedconfigurationsforuserMethods<'a, C>
Sourcepub fn delete(
&self,
enterprise_id: &str,
user_id: &str,
managed_configuration_for_user_id: &str,
) -> ManagedconfigurationsforuserDeleteCall<'a, C>
pub fn delete( &self, enterprise_id: &str, user_id: &str, managed_configuration_for_user_id: &str, ) -> ManagedconfigurationsforuserDeleteCall<'a, C>
Create a builder to help you perform the following task:
Removes a per-user managed configuration for an app for the specified user.
Arguments
enterpriseId- The ID of the enterprise.userId- The ID of the user.managedConfigurationForUserId- The ID of the managed configuration (a product ID), e.g. “app:com.google.android.gm”.
Sourcepub fn get(
&self,
enterprise_id: &str,
user_id: &str,
managed_configuration_for_user_id: &str,
) -> ManagedconfigurationsforuserGetCall<'a, C>
pub fn get( &self, enterprise_id: &str, user_id: &str, managed_configuration_for_user_id: &str, ) -> ManagedconfigurationsforuserGetCall<'a, C>
Create a builder to help you perform the following task:
Retrieves details of a per-user managed configuration for an app for the specified user.
Arguments
enterpriseId- The ID of the enterprise.userId- The ID of the user.managedConfigurationForUserId- The ID of the managed configuration (a product ID), e.g. “app:com.google.android.gm”.
Sourcepub fn list(
&self,
enterprise_id: &str,
user_id: &str,
) -> ManagedconfigurationsforuserListCall<'a, C>
pub fn list( &self, enterprise_id: &str, user_id: &str, ) -> ManagedconfigurationsforuserListCall<'a, C>
Create a builder to help you perform the following task:
Lists all the per-user managed configurations for the specified user. Only the ID is set.
Arguments
enterpriseId- The ID of the enterprise.userId- The ID of the user.
Sourcepub fn update(
&self,
request: ManagedConfiguration,
enterprise_id: &str,
user_id: &str,
managed_configuration_for_user_id: &str,
) -> ManagedconfigurationsforuserUpdateCall<'a, C>
pub fn update( &self, request: ManagedConfiguration, enterprise_id: &str, user_id: &str, managed_configuration_for_user_id: &str, ) -> ManagedconfigurationsforuserUpdateCall<'a, C>
Create a builder to help you perform the following task:
Adds or updates the managed configuration settings for an app for the specified user. If you support the Managed configurations iframe, you can apply managed configurations to a user by specifying an mcmId and its associated configuration variables (if any) in the request. Alternatively, all EMMs can apply managed configurations by passing a list of managed properties.
Arguments
request- No description provided.enterpriseId- The ID of the enterprise.userId- The ID of the user.managedConfigurationForUserId- The ID of the managed configuration (a product ID), e.g. “app:com.google.android.gm”.