pub struct NewPermissionsEvent {
pub approved_permissions: Option<Vec<String>>,
pub product_id: Option<String>,
pub requested_permissions: Option<Vec<String>>,
}Expand description
An event generated when new permissions are added to an app.
This type is not used in any activity, and only used as part of another schema.
Fields
approved_permissions: Option<Vec<String>>The set of permissions that the enterprise admin has already approved for this application. Use Permissions.Get on the EMM API to retrieve details about these permissions.
product_id: Option<String>The id of the product (e.g. “app:com.google.android.gm”) for which new permissions were added. This field will always be present.
requested_permissions: Option<Vec<String>>The set of permissions that the app is currently requesting. Use Permissions.Get on the EMM API to retrieve details about these permissions.