pub struct ServiceAccountKey {
pub data: Option<String>,
pub id: Option<String>,
pub public_data: Option<String>,
pub type_: Option<String>,
}Expand description
Deprecated: New integrations cannot use this method and can refer to our new recommendations
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- insert serviceaccountkeys (request|response)
Fields
data: Option<String>The body of the private key credentials file, in string format. This is only populated when the ServiceAccountKey is created, and is not stored by Google.
id: Option<String>An opaque, unique identifier for this ServiceAccountKey. Assigned by the server.
public_data: Option<String>Public key data for the credentials file. This is an X.509 cert. If you are using the googleCredentials key type, this is identical to the cert that can be retrieved by using the X.509 cert url inside of the credentials file.
type_: Option<String>The file format of the generated key data.