pub struct ServiceaccountkeyMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on serviceaccountkey resources.
It is not used directly, but through the AndroidEnterprise hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_androidenterprise1 as androidenterprise1;
use androidenterprise1::{AndroidEnterprise, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = AndroidEnterprise::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `delete(...)`, `insert(...)` and `list(...)`
// to build up your call.
let rb = hub.serviceaccountkeys();Implementations
Sourceimpl<'a, C> ServiceaccountkeyMethods<'a, C>
impl<'a, C> ServiceaccountkeyMethods<'a, C>
Sourcepub fn delete(
&self,
enterprise_id: &str,
key_id: &str,
) -> ServiceaccountkeyDeleteCall<'a, C>
pub fn delete( &self, enterprise_id: &str, key_id: &str, ) -> ServiceaccountkeyDeleteCall<'a, C>
Create a builder to help you perform the following task:
Removes and invalidates the specified credentials for the service account associated with this enterprise. The calling service account must have been retrieved by calling Enterprises.GetServiceAccount and must have been set as the enterprise service account by calling Enterprises.SetAccount.
Arguments
enterpriseId- The ID of the enterprise.keyId- The ID of the key.
Sourcepub fn insert(
&self,
request: ServiceAccountKey,
enterprise_id: &str,
) -> ServiceaccountkeyInsertCall<'a, C>
pub fn insert( &self, request: ServiceAccountKey, enterprise_id: &str, ) -> ServiceaccountkeyInsertCall<'a, C>
Create a builder to help you perform the following task:
Generates new credentials for the service account associated with this enterprise. The calling service account must have been retrieved by calling Enterprises.GetServiceAccount and must have been set as the enterprise service account by calling Enterprises.SetAccount. Only the type of the key should be populated in the resource to be inserted.
Arguments
request- No description provided.enterpriseId- The ID of the enterprise.
Sourcepub fn list(&self, enterprise_id: &str) -> ServiceaccountkeyListCall<'a, C>
pub fn list(&self, enterprise_id: &str) -> ServiceaccountkeyListCall<'a, C>
Create a builder to help you perform the following task:
Lists all active credentials for the service account associated with this enterprise. Only the ID and key type are returned. The calling service account must have been retrieved by calling Enterprises.GetServiceAccount and must have been set as the enterprise service account by calling Enterprises.SetAccount.
Arguments
enterpriseId- The ID of the enterprise.