pub struct SignupInfo {
pub completion_token: Option<String>,
pub kind: Option<String>,
pub url: Option<String>,
}Expand description
A resource returned by the GenerateSignupUrl API, which contains the Signup URL and Completion Token.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- generate signup url enterprises (response)
Fields
completion_token: Option<String>An opaque token that will be required, along with the Enterprise Token, for obtaining the enterprise resource from CompleteSignup.
kind: Option<String>Deprecated.
url: Option<String>A URL under which the Admin can sign up for an enterprise. The page pointed to cannot be rendered in an iframe.