pub struct StoreCluster {
pub id: Option<String>,
pub name: Option<Vec<LocalizedText>>,
pub order_in_page: Option<String>,
pub product_id: Option<Vec<String>>,
}Expand description
Definition of a managed Google Play store cluster, a list of products displayed as part of a store page.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- get storelayoutclusters (response)
- insert storelayoutclusters (request|response)
- update storelayoutclusters (request|response)
Fields
id: Option<String>Unique ID of this cluster. Assigned by the server. Immutable once assigned.
name: Option<Vec<LocalizedText>>Ordered list of localized strings giving the name of this page. The text displayed is the one that best matches the user locale, or the first entry if there is no good match. There needs to be at least one entry.
order_in_page: Option<String>String (US-ASCII only) used to determine order of this cluster within the parent page’s elements. Page elements are sorted in lexicographic order of this field. Duplicated values are allowed, but ordering between elements with duplicate order is undefined. The value of this field is never visible to a user, it is used solely for the purpose of defining an ordering. Maximum length is 256 characters.
product_id: Option<Vec<String>>List of products in the order they are displayed in the cluster. There should not be duplicates within a cluster.